@@ -5,7 +5,7 @@ from typing import Union, Set
 from redbot.core import checks, Config, modlog, commands
 from redbot.core.bot import Red
 from redbot.core.i18n import Translator, cog_i18n
-from redbot.core.utils.chat_formatting import pagify
+from redbot.core.utils.chat_formatting import pagify, humanize_list
 
 _ = Translator("Filter", __file__)
 
@@ -17,7 +17,7 @@ class Filter(commands.Cog):
     def __init__(self, bot: Red):
         super().__init__()
         self.bot = bot
-        self.settings = Config.get_conf(self, 4766951341)
+        self.config = Config.get_conf(self, 4766951341)
         default_guild_settings = {
             "filter": [],
             "filterban_count": 0,
@@ -27,9 +27,9 @@ class Filter(commands.Cog):
         }
         default_member_settings = {"filter_count": 0, "next_reset_time": 0}
         default_channel_settings = {"filter": []}
-        self.settings.register_guild(**default_guild_settings)
-        self.settings.register_member(**default_member_settings)
-        self.settings.register_channel(**default_channel_settings)
+        self.config.register_guild(**default_guild_settings)
+        self.config.register_member(**default_member_settings)
+        self.config.register_channel(**default_channel_settings)
         self.register_task = self.bot.loop.create_task(self.register_filterban())
         self.pattern_cache = {}
 
@@ -62,7 +62,7 @@ class Filter(commands.Cog):
         The default name used is *John Doe*.
         """
         guild = ctx.guild
-        await self.settings.guild(guild).filter_default_name.set(name)
+        await self.config.guild(guild).filter_default_name.set(name)
         await ctx.send(_("The name to use on filtered names has been set."))
 
     @filterset.command(name="ban")
@@ -83,12 +83,14 @@ class Filter(commands.Cog):
             )
             return
         elif count == 0 and timeframe == 0:
-            await self.settings.guild(ctx.guild).filterban_count.set(0)
-            await self.settings.guild(ctx.guild).filterban_time.set(0)
+            async with self.config.guild(ctx.guild).all() as guild_data:
+                guild_data["filterban_count"] = 0
+                guild_data["filterban_time"] = 0
             await ctx.send(_("Autoban disabled."))
         else:
-            await self.settings.guild(ctx.guild).filterban_count.set(count)
-            await self.settings.guild(ctx.guild).filterban_time.set(timeframe)
+            async with self.config.guild(ctx.guild).all() as guild_data:
+                guild_data["filterban_count"] = count
+                guild_data["filterban_time"] = timeframe
             await ctx.send(_("Count and time have been set."))
 
     @commands.group(name="filter")
@@ -98,47 +100,53 @@ class Filter(commands.Cog):
         """Add or remove words from server filter.
 
         Use double quotes to add or remove sentences.
-
-        Using this command with no subcommands will send the list of
-        the server's filtered words.
         """
-        if ctx.invoked_subcommand is None:
-            server = ctx.guild
-            author = ctx.author
-            word_list = await self.settings.guild(server).filter()
-            if word_list:
-                words = ", ".join(word_list)
-                words = _("Filtered in this server:") + "\n\n" + words
-                try:
-                    for page in pagify(words, delims=[" ", "\n"], shorten_by=8):
-                        await author.send(page)
-                except discord.Forbidden:
-                    await ctx.send(_("I can't send direct messages to you."))
+        pass
+
+    @_filter.command(name="list")
+    async def _global_list(self, ctx: commands.Context):
+        """Send a list of this servers filtered words."""
+        server = ctx.guild
+        author = ctx.author
+        word_list = await self.config.guild(server).filter()
+        if not word_list:
+            await ctx.send(_("There is no current words setup to be filtered in this server."))
+            return
+        words = humanize_list(word_list)
+        words = _("Filtered in this server:") + "\n\n" + words
+        try:
+            for page in pagify(words, delims=[" ", "\n"], shorten_by=8):
+                await author.send(page)
+        except discord.Forbidden:
+            await ctx.send(_("I can't send direct messages to you."))
 
     @_filter.group(name="channel")
     async def _filter_channel(self, ctx: commands.Context):
         """Add or remove words from channel filter.
 
         Use double quotes to add or remove sentences.
-
-        Using this command with no subcommands will send the list of
-        the channel's filtered words.
         """
-        if ctx.invoked_subcommand is None:
-            channel = ctx.channel
-            author = ctx.author
-            word_list = await self.settings.channel(channel).filter()
-            if word_list:
-                words = ", ".join(word_list)
-                words = _("Filtered in this channel:") + "\n\n" + words
-                try:
-                    for page in pagify(words, delims=[" ", "\n"], shorten_by=8):
-                        await author.send(page)
-                except discord.Forbidden:
-                    await ctx.send(_("I can't send direct messages to you."))
+        pass
+
+    @_filter_channel.command(name="list")
+    async def _channel_list(self, ctx: commands.Context):
+        """Send the list of the channel's filtered words."""
+        channel = ctx.channel
+        author = ctx.author
+        word_list = await self.config.channel(channel).filter()
+        if not word_list:
+            await ctx.send(_("There is no current words setup to be filtered in this channel."))
+            return
+        words = humanize_list(word_list)
+        words = _("Filtered in this channel:") + "\n\n" + words
+        try:
+            for page in pagify(words, delims=[" ", "\n"], shorten_by=8):
+                await author.send(page)
+        except discord.Forbidden:
+            await ctx.send(_("I can't send direct messages to you."))
 
     @_filter_channel.command("add")
-    async def filter_channel_add(self, ctx: commands.Context, *, words: str):
+    async def filter_channel_add(self, ctx: commands.Context, *words: str):
         """Add words to the filter.
 
         Use double quotes to add sentences.
@@ -148,22 +156,7 @@ class Filter(commands.Cog):
         - `[p]filter channel add "This is a sentence"`
         """
         channel = ctx.channel
-        split_words = words.split()
-        word_list = []
-        tmp = ""
-        for word in split_words:
-            if not word.startswith('"') and not word.endswith('"') and not tmp:
-                word_list.append(word)
-            else:
-                if word.startswith('"'):
-                    tmp += word[1:] + " "
-                elif word.endswith('"'):
-                    tmp += word[:-1]
-                    word_list.append(tmp)
-                    tmp = ""
-                else:
-                    tmp += word + " "
-        added = await self.add_to_filter(channel, word_list)
+        added = await self.add_to_filter(channel, words)
         if added:
             self.invalidate_cache(ctx.guild, ctx.channel)
             await ctx.send(_("Words added to filter."))
@@ -171,7 +164,7 @@ class Filter(commands.Cog):
             await ctx.send(_("Words already in the filter."))
 
     @_filter_channel.command("remove")
-    async def filter_channel_remove(self, ctx: commands.Context, *, words: str):
+    async def filter_channel_remove(self, ctx: commands.Context, *words: str):
         """Remove words from the filter.
 
         Use double quotes to remove sentences.
@@ -181,22 +174,7 @@ class Filter(commands.Cog):
         - `[p]filter channel remove "This is a sentence"`
         """
         channel = ctx.channel
-        split_words = words.split()
-        word_list = []
-        tmp = ""
-        for word in split_words:
-            if not word.startswith('"') and not word.endswith('"') and not tmp:
-                word_list.append(word)
-            else:
-                if word.startswith('"'):
-                    tmp += word[1:] + " "
-                elif word.endswith('"'):
-                    tmp += word[:-1]
-                    word_list.append(tmp)
-                    tmp = ""
-                else:
-                    tmp += word + " "
-        removed = await self.remove_from_filter(channel, word_list)
+        removed = await self.remove_from_filter(channel, words)
         if removed:
             await ctx.send(_("Words removed from filter."))
             self.invalidate_cache(ctx.guild, ctx.channel)
@@ -204,7 +182,7 @@ class Filter(commands.Cog):
             await ctx.send(_("Those words weren't in the filter."))
 
     @_filter.command(name="add")
-    async def filter_add(self, ctx: commands.Context, *, words: str):
+    async def filter_add(self, ctx: commands.Context, *words: str):
         """Add words to the filter.
 
         Use double quotes to add sentences.
@@ -214,22 +192,7 @@ class Filter(commands.Cog):
         - `[p]filter add "This is a sentence"`
         """
         server = ctx.guild
-        split_words = words.split()
-        word_list = []
-        tmp = ""
-        for word in split_words:
-            if not word.startswith('"') and not word.endswith('"') and not tmp:
-                word_list.append(word)
-            else:
-                if word.startswith('"'):
-                    tmp += word[1:] + " "
-                elif word.endswith('"'):
-                    tmp += word[:-1]
-                    word_list.append(tmp)
-                    tmp = ""
-                else:
-                    tmp += word + " "
-        added = await self.add_to_filter(server, word_list)
+        added = await self.add_to_filter(server, words)
         if added:
             self.invalidate_cache(ctx.guild)
             await ctx.send(_("Words successfully added to filter."))
@@ -237,7 +200,7 @@ class Filter(commands.Cog):
             await ctx.send(_("Those words were already in the filter."))
 
     @_filter.command(name="delete", aliases=["remove", "del"])
-    async def filter_remove(self, ctx: commands.Context, *, words: str):
+    async def filter_remove(self, ctx: commands.Context, *words: str):
         """Remove words from the filter.
 
         Use double quotes to remove sentences.
@@ -247,22 +210,7 @@ class Filter(commands.Cog):
         - `[p]filter remove "This is a sentence"`
         """
         server = ctx.guild
-        split_words = words.split()
-        word_list = []
-        tmp = ""
-        for word in split_words:
-            if not word.startswith('"') and not word.endswith('"') and not tmp:
-                word_list.append(word)
-            else:
-                if word.startswith('"'):
-                    tmp += word[1:] + " "
-                elif word.endswith('"'):
-                    tmp += word[:-1]
-                    word_list.append(tmp)
-                    tmp = ""
-                else:
-                    tmp += word + " "
-        removed = await self.remove_from_filter(server, word_list)
+        removed = await self.remove_from_filter(server, words)
         if removed:
             self.invalidate_cache(ctx.guild)
             await ctx.send(_("Words successfully removed from filter."))
@@ -276,8 +224,10 @@ class Filter(commands.Cog):
         This is disabled by default.
         """
         guild = ctx.guild
-        current_setting = await self.settings.guild(guild).filter_names()
-        await self.settings.guild(guild).filter_names.set(not current_setting)
+
+        async with self.config.guild(guild).all() as guild_data:
+            current_setting = guild_data["filter_names"]
+            guild_data["filter_names"] = not current_setting
         if current_setting:
             await ctx.send(_("Names and nicknames will no longer be filtered."))
         else:
@@ -296,14 +246,14 @@ class Filter(commands.Cog):
     ) -> bool:
         added = False
         if isinstance(server_or_channel, discord.Guild):
-            async with self.settings.guild(server_or_channel).filter() as cur_list:
+            async with self.config.guild(server_or_channel).filter() as cur_list:
                 for w in words:
                     if w.lower() not in cur_list and w:
                         cur_list.append(w.lower())
                         added = True
 
         elif isinstance(server_or_channel, discord.TextChannel):
-            async with self.settings.channel(server_or_channel).filter() as cur_list:
+            async with self.config.channel(server_or_channel).filter() as cur_list:
                 for w in words:
                     if w.lower not in cur_list and w:
                         cur_list.append(w.lower())
@@ -316,14 +266,14 @@ class Filter(commands.Cog):
     ) -> bool:
         removed = False
         if isinstance(server_or_channel, discord.Guild):
-            async with self.settings.guild(server_or_channel).filter() as cur_list:
+            async with self.config.guild(server_or_channel).filter() as cur_list:
                 for w in words:
                     if w.lower() in cur_list:
                         cur_list.remove(w.lower())
                         removed = True
 
         elif isinstance(server_or_channel, discord.TextChannel):
-            async with self.settings.channel(server_or_channel).filter() as cur_list:
+            async with self.config.channel(server_or_channel).filter() as cur_list:
                 for w in words:
                     if w.lower() in cur_list:
                         cur_list.remove(w.lower())
@@ -347,9 +297,9 @@ class Filter(commands.Cog):
         try:
             pattern = self.pattern_cache[(guild, channel)]
         except KeyError:
-            word_list = set(await self.settings.guild(guild).filter())
+            word_list = set(await self.config.guild(guild).filter())
             if channel:
-                word_list |= set(await self.settings.channel(channel).filter())
+                word_list |= set(await self.config.channel(channel).filter())
 
             if word_list:
                 pattern = re.compile(
@@ -365,21 +315,23 @@ class Filter(commands.Cog):
         return hits
 
     async def check_filter(self, message: discord.Message):
-        server = message.guild
+        guild = message.guild
         author = message.author
-
-        filter_count = await self.settings.guild(server).filterban_count()
-        filter_time = await self.settings.guild(server).filterban_time()
-        user_count = await self.settings.member(author).filter_count()
-        next_reset_time = await self.settings.member(author).next_reset_time()
+        guild_data = await self.config.guild(guild).all()
+        member_data = await self.config.member(author).all()
+        filter_count = guild_data["filterban_count"]
+        filter_time = guild_data["filterban_time"]
+        user_count = member_data["filter_count"]
+        next_reset_time = member_data["next_reset_time"]
 
         if filter_count > 0 and filter_time > 0:
             if message.created_at.timestamp() >= next_reset_time:
                 next_reset_time = message.created_at.timestamp() + filter_time
-                await self.settings.member(author).next_reset_time.set(next_reset_time)
-                if user_count > 0:
-                    user_count = 0
-                    await self.settings.member(author).filter_count.set(user_count)
+                async with self.config.member(author).all() as member_data:
+                    member_data["next_reset_time"] = next_reset_time
+                    if user_count > 0:
+                        user_count = 0
+                        member_data["filter_count"] = user_count
 
         hits = await self.filter_hits(message.content, message.channel)
 
@@ -392,24 +344,24 @@ class Filter(commands.Cog):
                 self.bot.dispatch("filter_message_delete", message, hits)
                 if filter_count > 0 and filter_time > 0:
                     user_count += 1
-                    await self.settings.member(author).filter_count.set(user_count)
+                    await self.config.member(author).filter_count.set(user_count)
                     if (
                         user_count >= filter_count
                         and message.created_at.timestamp() < next_reset_time
                     ):
                         reason = _("Autoban (too many filtered messages.)")
                         try:
-                            await server.ban(author, reason=reason)
+                            await guild.ban(author, reason=reason)
                         except discord.HTTPException:
                             pass
                         else:
                             await modlog.create_case(
                                 self.bot,
-                                server,
+                                guild,
                                 message.created_at,
                                 "filterban",
                                 author,
-                                server.me,
+                                guild.me,
                                 reason,
                             )
 
@@ -449,12 +401,13 @@ class Filter(commands.Cog):
             return  # Discord Hierarchy applies to nicks
         if await self.bot.is_automod_immune(member):
             return
-        if not await self.settings.guild(member.guild).filter_names():
+        guild_data = await self.config.guild(member.guild).all()
+        if not guild_data["filter_names"]:
             return
 
         if await self.filter_hits(member.display_name, member.guild):
 
-            name_to_use = await self.settings.guild(member.guild).filter_default_name()
+            name_to_use = guild_data["filter_default_name"]
             reason = _("Filtered nickname") if member.nick else _("Filtered name")
             try:
                 await member.edit(nick=name_to_use, reason=reason)
