@@ -7,7 +7,7 @@ from typing import Optional, Union
 import discord
 from redbot.core import commands, i18n, checks, modlog
 from redbot.core.utils import AsyncIter
-from redbot.core.utils.chat_formatting import pagify, humanize_number, bold
+from redbot.core.utils.chat_formatting import pagify, humanize_number, bold, humanize_list
 from redbot.core.utils.mod import is_allowed_by_hierarchy, get_audit_reason
 from .abc import MixinMeta
 from .converters import RawUserIds
@@ -78,7 +78,7 @@ class KickBanMixin(MixinMeta):
                 "hierarchy."
             )
         elif guild.me.top_role <= user.top_role or user == guild.owner:
-            return _("I cannot do that due to discord hierarchy rules")
+            return _("I cannot do that due to discord hierarchy rules.")
         elif not (0 <= days <= 7):
             return _("Invalid days. Must be between 0 and 7.")
 
@@ -101,14 +101,19 @@ class KickBanMixin(MixinMeta):
         try:
             await guild.ban(user, reason=audit_reason, delete_message_days=days)
             log.info(
-                "{}({}) banned {}({}), deleting {} days worth of messages".format(
+                "{}({}) banned {}({}), deleting {} days worth of messages.".format(
                     author.name, author.id, user.name, user.id, str(days)
                 )
             )
         except discord.Forbidden:
             return _("I'm not allowed to do that.")
         except Exception as e:
-            return e  # TODO: improper return type? Is this intended to be re-raised?
+            log.exception(
+                "{}({}) attempted to kick {}({}), but an error occurred.".format(
+                    author.name, author.id, user.name, user.id
+                )
+            )
+            return _("An unexpected error occurred.")
 
         if create_modlog_case:
             try:
@@ -156,7 +161,7 @@ class KickBanMixin(MixinMeta):
                                 if e.code == 50013 or e.status == 403:
                                     log.info(
                                         f"Failed to unban ({uid}) user from "
-                                        f"{guild.name}({guild.id}) guild due to permissions"
+                                        f"{guild.name}({guild.id}) guild due to permissions."
                                     )
                                     break  # skip the rest of this guild
                                 log.info(f"Failed to unban member: error code: {e.code}")
@@ -195,7 +200,7 @@ class KickBanMixin(MixinMeta):
             )
             return
         elif ctx.guild.me.top_role <= user.top_role or user == ctx.guild.owner:
-            await ctx.send(_("I cannot do that due to discord hierarchy rules"))
+            await ctx.send(_("I cannot do that due to discord hierarchy rules."))
             return
         audit_reason = get_audit_reason(author, reason)
         toggle = await self.config.guild(guild).dm_on_kickban()
@@ -216,7 +221,11 @@ class KickBanMixin(MixinMeta):
         except discord.errors.Forbidden:
             await ctx.send(_("I'm not allowed to do that."))
         except Exception as e:
-            print(e)
+            log.exception(
+                "{}({}) attempted to kick {}({}), but an error occurred.".format(
+                    author.name, author.id, user.name, user.id
+                )
+            )
         else:
             try:
                 await modlog.create_case(
@@ -283,6 +292,7 @@ class KickBanMixin(MixinMeta):
         using this command"""
         banned = []
         errors = {}
+        upgrades = []
 
         async def show_results():
             text = _("Banned {num} users from the server.").format(
@@ -291,6 +301,11 @@ class KickBanMixin(MixinMeta):
             if errors:
                 text += _("\nErrors:\n")
                 text += "\n".join(errors.values())
+            if upgrades:
+                text += _(
+                    "\nFollowing user IDs have been upgraded from a temporary to a permanent ban:\n"
+                )
+                text += humanize_list(upgrades)
 
             for p in pagify(text):
                 await ctx.send(p)
@@ -317,13 +332,19 @@ class KickBanMixin(MixinMeta):
         if not guild.me.guild_permissions.ban_members:
             return await ctx.send(_("I lack the permissions to do this."))
 
+        tempbans = await self.config.guild(guild).current_tempbans()
+
         ban_list = await guild.bans()
         for entry in ban_list:
             for user_id in user_ids:
                 if entry.user.id == user_id:
-                    errors[user_id] = _("User {user_id} is already banned.").format(
-                        user_id=user_id
-                    )
+                    if user_id in tempbans:
+                        # We need to check if a user is tempbanned here because otherwise they won't be processed later on.
+                        continue
+                    else:
+                        errors[user_id] = _("User {user_id} is already banned.").format(
+                            user_id=user_id
+                        )
 
         user_ids = remove_processed(user_ids)
 
@@ -334,21 +355,25 @@ class KickBanMixin(MixinMeta):
         for user_id in user_ids:
             user = guild.get_member(user_id)
             if user is not None:
-                # Instead of replicating all that handling... gets attr from decorator
-                try:
-                    result = await self.ban_user(
-                        user=user, ctx=ctx, days=days, reason=reason, create_modlog_case=True
-                    )
-                    if result is True:
-                        banned.append(user_id)
-                    else:
+                if user_id in tempbans:
+                    # We need to check if a user is tempbanned here because otherwise they won't be processed later on.
+                    continue
+                else:
+                    # Instead of replicating all that handling... gets attr from decorator
+                    try:
+                        result = await self.ban_user(
+                            user=user, ctx=ctx, days=days, reason=reason, create_modlog_case=True
+                        )
+                        if result is True:
+                            banned.append(user_id)
+                        else:
+                            errors[user_id] = _("Failed to ban user {user_id}: {reason}").format(
+                                user_id=user_id, reason=result
+                            )
+                    except Exception as e:
                         errors[user_id] = _("Failed to ban user {user_id}: {reason}").format(
-                            user_id=user_id, reason=result
+                            user_id=user_id, reason=e
                         )
-                except Exception as e:
-                    errors[user_id] = _("Failed to ban user {user_id}: {reason}").format(
-                        user_id=user_id, reason=e
-                    )
 
         user_ids = remove_processed(user_ids)
 
@@ -360,19 +385,32 @@ class KickBanMixin(MixinMeta):
             user = discord.Object(id=user_id)
             audit_reason = get_audit_reason(author, reason)
             queue_entry = (guild.id, user_id)
-            try:
-                await guild.ban(user, reason=audit_reason, delete_message_days=days)
-                log.info("{}({}) hackbanned {}".format(author.name, author.id, user_id))
-            except discord.NotFound:
-                errors[user_id] = _("User {user_id} does not exist.").format(user_id=user_id)
-                continue
-            except discord.Forbidden:
-                errors[user_id] = _("Could not ban {user_id}: missing permissions.").format(
-                    user_id=user_id
-                )
-                continue
-            else:
-                banned.append(user_id)
+            async with self.config.guild(guild).current_tempbans() as tempbans:
+                if user_id in tempbans:
+                    tempbans.remove(user_id)
+                    upgrades.append(str(user_id))
+                    log.info(
+                        "{}({}) upgraded the tempban for {} to a permaban.".format(
+                            author.name, author.id, user_id
+                        )
+                    )
+                    banned.append(user_id)
+                else:
+                    try:
+                        await guild.ban(user, reason=audit_reason, delete_message_days=days)
+                        log.info("{}({}) hackbanned {}".format(author.name, author.id, user_id))
+                    except discord.NotFound:
+                        errors[user_id] = _("User {user_id} does not exist.").format(
+                            user_id=user_id
+                        )
+                        continue
+                    except discord.Forbidden:
+                        errors[user_id] = _(
+                            "Could not ban {user_id}: missing permissions."
+                        ).format(user_id=user_id)
+                        continue
+                    else:
+                        banned.append(user_id)
 
             try:
                 await modlog.create_case(
@@ -395,15 +433,40 @@ class KickBanMixin(MixinMeta):
     @commands.bot_has_permissions(ban_members=True)
     @checks.admin_or_permissions(ban_members=True)
     async def tempban(
-        self, ctx: commands.Context, user: discord.Member, days: int = 1, *, reason: str = None
+        self,
+        ctx: commands.Context,
+        user: discord.Member,
+        duration: Optional[commands.TimedeltaConverter] = timedelta(days=1),
+        days: Optional[int] = 0,
+        *,
+        reason: str = None,
     ):
         """Temporarily ban a user from this server."""
         guild = ctx.guild
         author = ctx.author
-        days_delta = timedelta(days=int(days))
-        unban_time = datetime.utcnow() + days_delta
+        unban_time = datetime.utcnow() + duration
 
-        invite = await self.get_invite_for_reinvite(ctx, int(days_delta.total_seconds() + 86400))
+        if author == user:
+            await ctx.send(
+                _("I cannot let you do that. Self-harm is bad {}").format("\N{PENSIVE FACE}")
+            )
+            return
+        elif not await is_allowed_by_hierarchy(self.bot, self.config, guild, author, user):
+            await ctx.send(
+                _(
+                    "I cannot let you do that. You are "
+                    "not higher than the user in the role "
+                    "hierarchy."
+                )
+            )
+            return
+        elif guild.me.top_role <= user.top_role or user == guild.owner:
+            await ctx.send(_("I cannot do that due to discord hierarchy rules"))
+            return
+        elif not (0 <= days <= 7):
+            await ctx.send(_("Invalid days. Must be between 0 and 7."))
+            return
+        invite = await self.get_invite_for_reinvite(ctx, int(duration.total_seconds() + 86400))
         if invite is None:
             invite = ""
 
@@ -414,22 +477,20 @@ class KickBanMixin(MixinMeta):
 
         with contextlib.suppress(discord.HTTPException):
             # We don't want blocked DMs preventing us from banning
-            await user.send(
-                _(
-                    "You have been temporarily banned from {server_name} until {date}. "
-                    "Here is an invite for when your ban expires: {invite_link}"
-                ).format(
-                    server_name=guild.name,
-                    date=unban_time.strftime("%m-%d-%Y %H:%M:%S"),
-                    invite_link=invite,
-                )
+            msg = _("You have been temporarily banned from {server_name} until {date}.").format(
+                server_name=guild.name, date=unban_time.strftime("%m-%d-%Y %H:%M:%S")
             )
+            if invite:
+                msg += _(" Here is an invite for when your ban expires: {invite_link}").format(
+                    invite_link=invite
+                )
+            await user.send(msg)
         try:
-            await guild.ban(user)
+            await guild.ban(user, reason=reason, delete_message_days=days)
         except discord.Forbidden:
             await ctx.send(_("I can't do that for some reason."))
         except discord.HTTPException:
-            await ctx.send(_("Something went wrong while banning"))
+            await ctx.send(_("Something went wrong while banning."))
         else:
             try:
                 await modlog.create_case(
@@ -444,7 +505,7 @@ class KickBanMixin(MixinMeta):
                 )
             except RuntimeError as e:
                 await ctx.send(e)
-            await ctx.send(_("Done. Enough chaos for now"))
+            await ctx.send(_("Done. Enough chaos for now."))
 
     @commands.command()
     @commands.guild_only()
@@ -497,17 +558,25 @@ class KickBanMixin(MixinMeta):
                 await msg.delete()
             return
         except discord.HTTPException as e:
-            print(e)
+            log.exception(
+                "{}({}) attempted to softban {}({}), but an error occurred trying to ban them.".format(
+                    author.name, author.id, user.name, user.id
+                )
+            )
             return
         try:
             await guild.unban(user)
         except discord.HTTPException as e:
-            print(e)
+            log.exception(
+                "{}({}) attempted to softban {}({}), but an error occurred trying to unban them.".format(
+                    author.name, author.id, user.name, user.id
+                )
+            )
             return
         else:
             log.info(
                 "{}({}) softbanned {}({}), deleting 1 day worth "
-                "of messages".format(author.name, author.id, user.name, user.id)
+                "of messages.".format(author.name, author.id, user.name, user.id)
             )
             try:
                 await modlog.create_case(
@@ -551,13 +620,12 @@ class KickBanMixin(MixinMeta):
         # Store this channel for the case channel.
 
         try:
-            await member.move_to(discord.Object(id=None))
-            # Work around till we get D.py 1.1.0, whereby we can directly do None.
+            await member.move_to(None)
         except discord.Forbidden:  # Very unlikely that this will ever occur
             await ctx.send(_("I am unable to kick this member from the voice channel."))
             return
         except discord.HTTPException:
-            await ctx.send(_("Something went wrong while attempting to kick that member"))
+            await ctx.send(_("Something went wrong while attempting to kick that member."))
             return
         else:
             try:
@@ -599,7 +667,7 @@ class KickBanMixin(MixinMeta):
         try:
             await guild.unban(user, reason=audit_reason)
         except discord.HTTPException:
-            await ctx.send(_("Something went wrong while attempting to unban that user"))
+            await ctx.send(_("Something went wrong while attempting to unban that user."))
             return
         else:
             try:
@@ -616,7 +684,7 @@ class KickBanMixin(MixinMeta):
                 )
             except RuntimeError as e:
                 await ctx.send(e)
-            await ctx.send(_("Unbanned that user from this server"))
+            await ctx.send(_("Unbanned that user from this server."))
 
         if await self.config.guild(guild).reinvite_on_unban():
             user = ctx.bot.get_user(user_id)
