@@ -1,5 +1,6 @@
 import contextlib
 from collections import namedtuple
+from copy import copy
 from typing import Union, Optional
 
 import discord
@@ -29,6 +30,7 @@ class Warnings(commands.Cog):
         "reasons": {},
         "allow_custom_reasons": False,
         "toggle_dm": True,
+        "show_mod": False,
         "warn_channel": None,
         "toggle_channel": False,
     }
@@ -95,6 +97,24 @@ class Warnings(commands.Cog):
         else:
             await ctx.send(_("Warnings will no longer be sent to users DMs."))
 
+    @warningset.command()
+    @commands.guild_only()
+    async def showmoderator(self, ctx, true_or_false: bool):
+        """Decide whether the name of the moderator warning a user should be included in the DM to that user."""
+        await self.config.guild(ctx.guild).show_mod.set(true_or_false)
+        if true_or_false:
+            await ctx.send(
+                _(
+                    "I will include the name of the moderator who issued the warning when sending a DM to a user."
+                )
+            )
+        else:
+            await ctx.send(
+                _(
+                    "I will not include the name of the moderator who issued the warning when sending a DM to a user."
+                )
+            )
+
     @warningset.command()
     @commands.guild_only()
     async def warnchannel(self, ctx: commands.Context, channel: discord.TextChannel = None):
@@ -326,26 +346,32 @@ class Warnings(commands.Cog):
         if user.bot:
             await ctx.send(_("You cannot warn other bots."))
             return
-        custom_allowed = await self.config.guild(ctx.guild).allow_custom_reasons()
-        guild_settings = self.config.guild(ctx.guild)
+        guild_settings = await self.config.guild(ctx.guild).all()
+        custom_allowed = guild_settings["allow_custom_reasons"]
+
         reason_type = None
-        async with guild_settings.reasons() as registered_reasons:
-            if reason.lower() not in registered_reasons:
+        async with self.config.guild(ctx.guild).reasons() as registered_reasons:
+            if (reason_type := registered_reasons.get(reason.lower())) is None:
                 msg = _("That is not a registered reason!")
                 if custom_allowed:
                     reason_type = {"description": reason, "points": points}
-                elif (
-                    ctx.guild.owner == ctx.author
-                    or ctx.channel.permissions_for(ctx.author).administrator
-                    or await ctx.bot.is_owner(ctx.author)
-                ):
-                    msg += " " + _(
-                        "Do `{prefix}warningset allowcustomreasons true` to enable custom "
-                        "reasons."
-                    ).format(prefix=ctx.clean_prefix)
+                else:
+                    # logic taken from `[p]permissions canrun`
+                    fake_message = copy(ctx.message)
+                    fake_message.content = f"{ctx.prefix}warningset allowcustomreasons"
+                    fake_context = await ctx.bot.get_context(fake_message)
+                    try:
+                        can = await self.allowcustomreasons.can_run(
+                            fake_context, check_all_parents=True, change_permission_state=False
+                        )
+                    except commands.CommandError:
+                        can = False
+                    if can:
+                        msg += " " + _(
+                            "Do `{prefix}warningset allowcustomreasons true` to enable custom "
+                            "reasons."
+                        ).format(prefix=ctx.clean_prefix)
                     return await ctx.send(msg)
-            else:
-                reason_type = registered_reasons[reason.lower()]
         if reason_type is None:
             return
         member_settings = self.config.member(user)
@@ -363,13 +389,15 @@ class Warnings(commands.Cog):
         await member_settings.total_points.set(current_point_count)
 
         await warning_points_add_check(self.config, ctx, user, current_point_count)
-        dm = await self.config.guild(ctx.guild).toggle_dm()
+        dm = guild_settings["toggle_dm"]
+        showmod = guild_settings["show_mod"]
         dm_failed = False
         if dm:
-            em = discord.Embed(
-                title=_("Warning from {user}").format(user=ctx.author),
-                description=reason_type["description"],
-            )
+            if showmod:
+                title = _("Warning from {user}").format(user=ctx.author)
+            else:
+                title = _("Warning")
+            em = discord.Embed(title=title, description=reason_type["description"],)
             em.add_field(name=_("Points"), value=str(reason_type["points"]))
             try:
                 await user.send(
@@ -389,18 +417,19 @@ class Warnings(commands.Cog):
                 ).format(user=user.mention)
             )
 
-        toggle_channel = await self.config.guild(guild).toggle_channel()
+        toggle_channel = guild_settings["toggle_channel"]
         if toggle_channel:
-            em = discord.Embed(
-                title=_("Warning from {user}").format(user=ctx.author),
-                description=reason_type["description"],
-            )
+            if showmod:
+                title = _("Warning from {user}").format(user=ctx.author)
+            else:
+                title = _("Warning")
+            em = discord.Embed(title=title, description=reason_type["description"],)
             em.add_field(name=_("Points"), value=str(reason_type["points"]))
-            warn_channel = self.bot.get_channel(await self.config.guild(guild).warn_channel())
+            warn_channel = self.bot.get_channel(guild_settings["warn_channel"])
             if warn_channel:
-                if channel.permissions_for(guild.me).send_messages:
+                if warn_channel.permissions_for(guild.me).send_messages:
                     with contextlib.suppress(discord.HTTPException):
-                        await channel.send(
+                        await warn_channel.send(
                             _("{user} has been warned.").format(user=user.mention), embed=em,
                         )
 
